@@ -255,8 +255,10 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 'rm', '-f', 'boot', '&&',
                 'ln', '-s', '.', 'boot'
             ]
+            # not every filesystem supports symlinks, and the link is optional
+            # therefore don't fail in case the link cannot be created
             Command.run(
-                ['bash', '-c', ' '.join(bash_command)]
+                ['bash', '-c', ' '.join(bash_command)], raise_on_error=False
             )
 
         # Patch the written grub config file to actually work:
@@ -635,11 +637,13 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         * GRUB_TIMEOUT
         * GRUB_TIMEOUT_STYLE
         * SUSE_BTRFS_SNAPSHOT_BOOTING
+        * SUSE_REMOVE_LINUX_ROOT_PARAM
         * GRUB_BACKGROUND
         * GRUB_THEME
         * GRUB_USE_LINUXEFI
         * GRUB_USE_INITRDEFI
         * GRUB_SERIAL_COMMAND
+        * GRUB_CMDLINE_LINUX
         * GRUB_CMDLINE_LINUX_DEFAULT
         * GRUB_GFXMODE
         * GRUB_TERMINAL
@@ -657,6 +661,14 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             r'(^root=[^\s]+)|( root=[^\s]+)', '', self.cmdline
         ).strip()
         if self.persistency_type == 'by-label':
+            label = re.search(r'(^root=[^\s]+)|( root=[^\s]+)', self.cmdline)
+            if label:
+                for match in label.groups():
+                    if match and 'LABEL' in match:
+                        grub_default_entries['GRUB_CMDLINE_LINUX'] = \
+                            '"{0}"'.format(match.strip())
+                        grub_default_entries['SUSE_REMOVE_LINUX_ROOT_PARAM'] = \
+                            'true'
             grub_default_entries['GRUB_ENABLE_LINUX_LABEL'] = 'true'
             grub_default_entries['GRUB_DISABLE_LINUX_UUID'] = 'true'
         elif self.persistency_type == 'by-partuuid':
