@@ -146,6 +146,7 @@ class DiskBuilder:
         self.disk_resize_requested = \
             xml_state.get_oemconfig_oem_resize()
         self.swap_mbytes = xml_state.get_oemconfig_swap_mbytes()
+        self.disk_start_sector = xml_state.get_disk_start_sector()
         self.disk_setup = DiskSetup(
             xml_state, root_dir
         )
@@ -276,7 +277,7 @@ class DiskBuilder:
 
         disk = Disk(
             self.firmware.get_partition_table_type(), loop_provider,
-            self.xml_state.get_disk_start_sector(),
+            self.disk_start_sector,
             extended_layout=bool(self.dosparttable_extended_layout)
         )
 
@@ -513,9 +514,6 @@ class DiskBuilder:
             disk.storage_provider
         )
 
-        # set SELinux file security contexts if context exists
-        self._setup_selinux_file_contexts()
-
         # run pre sync script hook
         if self.system_setup.script_exists(
             defaults.PRE_DISK_SYNC_SCRIPT
@@ -693,13 +691,6 @@ class DiskBuilder:
 
         return result_instance
 
-    def _setup_selinux_file_contexts(self) -> None:
-        security_context = '/etc/selinux/targeted/contexts/files/file_contexts'
-        if os.path.exists(self.root_dir + security_context):
-            self.system_setup.set_selinux_file_contexts(
-                security_context
-            )
-
     def _install_image_requested(self) -> bool:
         return bool(
             self.install_iso or self.install_stick or self.install_pxe
@@ -755,9 +746,33 @@ class DiskBuilder:
                             device_map[map_name],
                             f'{self.root_dir}{ptable_entry.mountpoint}/'
                         )
-                        filesystem.create_on_device(
-                            label=map_name.upper()
-                        )
+                        if ptable_entry.filesystem == 'squashfs':
+                            squashed_root_file = Temporary().new_file()
+                            filesystem.create_on_file(
+                                filename=squashed_root_file.name,
+                                exclude=[Defaults.get_shared_cache_location()]
+                            )
+                            readonly_target = device_map[map_name].get_device()
+                            readonly_target_bytesize = device_map[map_name].get_byte_size(
+                                readonly_target
+                            )
+                            log.info(
+                                '--> Dumping {0!r} file({1} bytes) -> {2}({3} bytes)'.format(
+                                    map_name, os.path.getsize(squashed_root_file.name),
+                                    readonly_target, readonly_target_bytesize
+                                )
+                            )
+                            Command.run(
+                                [
+                                    'dd',
+                                    'if=%s' % squashed_root_file.name,
+                                    'of=%s' % readonly_target
+                                ]
+                            )
+                        else:
+                            filesystem.create_on_device(
+                                label=map_name.upper()
+                            )
                         filesystem_dict[map_name] = filesystem
         return filesystem_dict
 
@@ -973,6 +988,10 @@ class DiskBuilder:
             log.info('--> setting active flag to primary PReP partition')
             disk.activate_boot_partition()
 
+        if not self.firmware.efi_mode() and self.disk_start_sector:
+            log.info(f'--> setting start sector to: {self.disk_start_sector}')
+            disk.set_start_sector(self.disk_start_sector)
+
         if self.firmware.efi_mode():
             if self.force_mbr:
                 log.info('--> converting partition table to MBR')
@@ -1123,16 +1142,20 @@ class DiskBuilder:
         if not options:
             options = ['defaults']
         block_operation = BlockID(device)
+        filesystem = block_operation.get_filesystem()
         if self.volume_manager_name and self.volume_manager_name == 'lvm' \
            and (mount_point == '/' or mount_point == 'swap'):
             fstab_entry = ' '.join(
                 [
                     device, mount_point,
-                    block_operation.get_filesystem(), ','.join(options), check
+                    filesystem, ','.join(options), check
                 ]
             )
         else:
-            if self.persistency_type == 'by-label':
+            if filesystem == 'squashfs':
+                # squashfs does not provide a label or uuid
+                blkid_type = 'PARTUUID'
+            elif self.persistency_type == 'by-label':
                 blkid_type = 'LABEL'
             elif self.persistency_type == 'by-partuuid':
                 blkid_type = 'PARTUUID'
@@ -1142,7 +1165,7 @@ class DiskBuilder:
             fstab_entry = ' '.join(
                 [
                     blkid_type + '=' + device_id, mount_point,
-                    block_operation.get_filesystem(), ','.join(options), check
+                    filesystem, ','.join(options), check
                 ]
             )
         self.fstab.add_entry(fstab_entry)
@@ -1253,17 +1276,20 @@ class DiskBuilder:
         for map_name in sorted(system_custom_parts.keys()):
             system_custom_part = system_custom_parts[map_name]
             log.info('--> Syncing custom partition(s) data')
-            system_custom_part.sync_data()
+            if not system_custom_part.filename:
+                system_custom_part.sync_data()
             if device_map.get(f'{map_name}clone1'):
                 log.info(
-                    f'--> Dumping {map_name} clone data at extra partition'
+                    f'--> Dumping {map_name!r} clone data at extra partition'
                 )
+                system_custom_part.umount()
                 system_custom_part_clone = CloneDevice(
                     system_custom_part.device_provider, self.root_dir
                 )
                 system_custom_part_clone.clone(
                     self._get_clone_devices(f'{map_name}clone', device_map)
                 )
+                system_custom_part.mount()
 
         if system_efi:
             log.info('--> Syncing EFI boot data to EFI partition')
@@ -1278,9 +1304,11 @@ class DiskBuilder:
                 log.info(
                     '--> Dumping boot clone data at extra partition'
                 )
+                system_boot.umount()
                 CloneDevice(system_boot.device_provider, self.root_dir).clone(
                     self._get_clone_devices('bootclone', device_map)
                 )
+                system_boot.mount()
 
         log.info('--> Syncing root filesystem data')
         if self.root_filesystem_is_overlay:
@@ -1411,9 +1439,17 @@ class DiskBuilder:
                 log.info(
                     '--> Dumping root clone data at extra partition'
                 )
+                if self.volume_manager_name:
+                    system.umount_volumes()
+                else:
+                    system.umount()
                 CloneDevice(device_map['origin_root'], self.root_dir).clone(
                     self._get_clone_devices('rootclone', device_map)
                 )
+                if self.volume_manager_name:
+                    system.mount_volumes()
+                else:
+                    system.mount()
 
         if self.integrity_root and \
            self.root_filesystem_embed_integrity_metadata:
