@@ -60,10 +60,15 @@ unit_type = NamedTuple(
 
 
 # Default module variables
+DM_METADATA_FORMAT_VERSION = '1'
+DM_METADATA_OFFSET = 4096  # 4kb
 VERITY_DATA_BLOCKSIZE = 4096  # 4kb
 VERITY_HASH_BLOCKSIZE = 4096  # 4kb
-VERIFICATION_METADATA_FORMAT_VERSION = '1'
-VERIFICATION_METADATA_OFFSET = 4096  # 4kb
+INTEGRITY_SECTOR_SIZE = 512
+
+INTEGRITY_ALGORITHM = 'sha256'
+INTEGRITY_KEY_ALGORITHM = 'hmac-sha256'
+
 UNIT = unit_type(byte='b', kb='k', mb='m', gb='g')
 POST_DISK_SYNC_SCRIPT = 'disk.sh'
 PRE_DISK_SYNC_SCRIPT = 'pre_disk_sync.sh'
@@ -336,7 +341,7 @@ class Defaults:
         ]
 
     @staticmethod
-    def get_exclude_list_for_root_data_sync():
+    def get_exclude_list_for_root_data_sync(no_tmpdirs: bool = True):
         """
         Provides the list of files or folders that are created
         by KIWI for its own purposes. Those files should be not
@@ -347,7 +352,11 @@ class Defaults:
         :rtype: list
         """
         exclude_list = [
-            'image', '.profile', '.kconfig', 'run/*', 'tmp/*',
+            'image', '.profile', '.kconfig'
+        ]
+        if no_tmpdirs:
+            exclude_list += ['run/*', 'tmp/*']
+        exclude_list += [
             Defaults.get_buildservice_env_name(),
             Defaults.get_shared_cache_location()
         ]
