@@ -53,7 +53,8 @@ from kiwi.system.profile import Profile
 
 from kiwi.exceptions import (
     KiwiImportDescriptionError,
-    KiwiScriptFailed
+    KiwiScriptFailed,
+    KiwiFileNotFound
 )
 
 log: Any = logging.getLogger('kiwi')
@@ -491,12 +492,48 @@ class SystemSetup:
         :param str security_context_file: path file name
         """
         log.info('Processing SELinux file security contexts')
-        Command.run(
-            [
-                'chroot', self.root_dir,
-                'setfiles', security_context_file, '/', '-v', '-F'
-            ]
-        )
+        exclude = []
+        for devname in Defaults.get_exclude_list_for_non_physical_devices():
+            exclude.append('-e')
+            exclude.append(f'/{devname}')
+        # setfiles doesn't come with a stable command API and older versions
+        # needs a different invocation syntax. On older versions the usage
+        # information explicitly lists "setfiles -c policyfile" which is not
+        # present in newer versions. As setfiles doesn't come with a simple
+        # --version option, checking for this extra element in the usage
+        # was the only pointer I could come up with to differentiate the
+        # call options.
+        if CommandCapabilities.has_option_in_help(
+            'setfiles', 'setfiles -c policyfile', ['--help'],
+            root=self.root_dir, raise_on_error=False
+        ):
+            Command.run(
+                [
+                    'chroot', self.root_dir, 'setfiles',
+                    '-c', self._find_selinux_policy_file(
+                        self.xml_state.build_type.get_selinux_policy() or 'targeted'
+                    ), security_context_file
+                ]
+            )
+            Command.run(
+                [
+                    'chroot', self.root_dir, 'setfiles',
+                    '-F', '-p'
+                ] + exclude + [
+                    security_context_file, '/'
+                ]
+            )
+        else:
+            Command.run(
+                [
+                    'chroot', self.root_dir, 'setfiles',
+                    '-F', '-p', '-c', self._find_selinux_policy_file(
+                        self.xml_state.build_type.get_selinux_policy() or 'targeted'
+                    )
+                ] + exclude + [
+                    security_context_file, '/'
+                ]
+            )
 
     def setup_selinux_file_contexts(self) -> None:
         """
@@ -1321,3 +1358,20 @@ class SystemSetup:
                 )]
             )
         return group
+
+    def _find_selinux_policy_file(self, policy_name: str) -> str:
+        policy_dir = f'/etc/selinux/{policy_name}/policy'
+        policy_dir_in_root = self.root_dir + policy_dir
+        scandir_error = ''
+        try:
+            with os.scandir(policy_dir_in_root) as policy_path:
+                for entry in policy_path:
+                    if entry.is_file() and entry.name.startswith('policy.'):
+                        return os.path.join(policy_dir, entry.name)
+        except Exception as issue:
+            scandir_error = format(issue)
+        raise KiwiFileNotFound(
+            'Unable to find SELinux policy in {0!r} {1}'.format(
+                policy_dir_in_root, scandir_error
+            )
+        )
