@@ -566,7 +566,6 @@ class TestBootLoaderConfigGrub2:
         self.bootloader.theme = 'openSUSE'
         self.bootloader.displayname = 'Bob'
         self.firmware.efi_mode.return_value = 'efi'
-        self.bootloader.persistency_type = 'by-label'
 
         self.bootloader._setup_default_grub()
 
@@ -578,11 +577,9 @@ class TestBootLoaderConfigGrub2:
                 '/boot/grub2/themes/openSUSE/background.png'
             ),
             call('GRUB_CMDLINE_LINUX_DEFAULT', '"some-cmdline"'),
-            call('GRUB_DISABLE_LINUX_UUID', 'true'),
             call('GRUB_DISTRIBUTOR', '"Bob"'),
             call('GRUB_ENABLE_BLSCFG', 'true'),
             call('GRUB_ENABLE_CRYPTODISK', 'y'),
-            call('GRUB_ENABLE_LINUX_LABEL', 'true'),
             call('GRUB_GFXMODE', '800x600'),
             call(
                 'GRUB_SERIAL_COMMAND', '"serial --speed=38400"'
@@ -611,7 +608,7 @@ class TestBootLoaderConfigGrub2:
         self.bootloader.terminal = 'serial'
         self.bootloader.theme = 'openSUSE'
         self.bootloader.displayname = 'Bob'
-        self.bootloader.cmdline = 'root=UUID=foo'
+        self.bootloader.cmdline = 'root=LABEL=some-label'
         self.bootloader.persistency_type = 'by-label'
 
         self.bootloader._setup_default_grub()
@@ -622,6 +619,7 @@ class TestBootLoaderConfigGrub2:
                 'GRUB_BACKGROUND',
                 '/boot/grub2/themes/openSUSE/background.png'
             ),
+            call('GRUB_CMDLINE_LINUX', '"root=LABEL=some-label"'),
             call('GRUB_DISABLE_LINUX_UUID', 'true'),
             call('GRUB_DISTRIBUTOR', '"Bob"'),
             call('GRUB_ENABLE_BLSCFG', 'true'),
@@ -635,7 +633,8 @@ class TestBootLoaderConfigGrub2:
             call('GRUB_THEME', '/boot/grub2/themes/openSUSE/theme.txt'),
             call('GRUB_TIMEOUT', 10),
             call('GRUB_TIMEOUT_STYLE', 'countdown'),
-            call('SUSE_BTRFS_SNAPSHOT_BOOTING', 'true')
+            call('SUSE_BTRFS_SNAPSHOT_BOOTING', 'true'),
+            call('SUSE_REMOVE_LINUX_ROOT_PARAM', 'true')
         ]
 
     @patch('os.path.exists')
@@ -679,6 +678,50 @@ class TestBootLoaderConfigGrub2:
             call('SUSE_BTRFS_SNAPSHOT_BOOTING', 'true')
         ]
 
+    @patch('os.path.exists')
+    @patch('kiwi.bootloader.config.grub2.SysConfig')
+    @patch('kiwi.bootloader.config.grub2.Command.run')
+    def test_setup_default_grub_use_of_by_label(
+        self, mock_Command_run, mock_sysconfig, mock_exists
+    ):
+        grep_grub_option = Mock()
+        grep_grub_option.returncode = 0
+        mock_Command_run.return_value = grep_grub_option
+        grub_default = MagicMock()
+        mock_sysconfig.return_value = grub_default
+        mock_exists.return_value = True
+        self.bootloader.terminal = 'serial'
+        self.bootloader.theme = 'openSUSE'
+        self.bootloader.displayname = 'Bob'
+        self.bootloader.cmdline = 'abcd root=LABEL=foo console=tty0'
+        self.bootloader.persistency_type = 'by-label'
+
+        self.bootloader._setup_default_grub()
+
+        assert grub_default.__setitem__.call_args_list == [
+            call(
+                'GRUB_BACKGROUND',
+                '/boot/grub2/themes/openSUSE/background.png'
+            ),
+            call('GRUB_CMDLINE_LINUX', '"root=LABEL=foo"'),
+            call('GRUB_CMDLINE_LINUX_DEFAULT', '"abcd console=tty0"'),
+            call('GRUB_DISABLE_LINUX_UUID', 'true'),
+            call('GRUB_DISTRIBUTOR', '"Bob"'),
+            call('GRUB_ENABLE_BLSCFG', 'true'),
+            call('GRUB_ENABLE_CRYPTODISK', 'y'),
+            call('GRUB_ENABLE_LINUX_LABEL', 'true'),
+            call('GRUB_GFXMODE', '800x600'),
+            call(
+                'GRUB_SERIAL_COMMAND', '"serial --speed=38400"'
+            ),
+            call('GRUB_TERMINAL', '"serial"'),
+            call('GRUB_THEME', '/boot/grub2/themes/openSUSE/theme.txt'),
+            call('GRUB_TIMEOUT', 10),
+            call('GRUB_TIMEOUT_STYLE', 'countdown'),
+            call('SUSE_BTRFS_SNAPSHOT_BOOTING', 'true'),
+            call('SUSE_REMOVE_LINUX_ROOT_PARAM', 'true'),
+        ]
+
     @patch('os.path.exists')
     @patch('kiwi.bootloader.config.grub2.SysConfig')
     def test_setup_sysconfig_bootloader(self, mock_sysconfig, mock_exists):
@@ -850,7 +893,7 @@ class TestBootLoaderConfigGrub2:
                     [
                         'bash', '-c',
                         'cd root_mount_point/boot && rm -f boot && ln -s . boot'
-                    ]
+                    ], raise_on_error=False
                 )
             ]
             mock_copy_grub_config_to_efi_path.assert_called_once_with(
