@@ -185,6 +185,13 @@ class TestDiskBuilder:
         kiwi.builder.disk.RaidDevice = Mock(
             return_value=self.raid_root
         )
+        self.integrity_root = Mock()
+        self.integrity_root.get_device.return_value = MappedDevice(
+            '/dev/integrityRoot', Mock()
+        )
+        kiwi.builder.disk.IntegrityDevice = Mock(
+            return_value=self.integrity_root
+        )
         self.luks_root = Mock()
         kiwi.builder.disk.LuksDevice = Mock(
             return_value=self.luks_root
@@ -309,10 +316,9 @@ class TestDiskBuilder:
         assert self.setup.export_modprobe_setup.call_args_list[0] == \
             call('boot_dir')
 
-        self.setup.set_selinux_file_contexts.assert_called_once_with(
-            '/etc/selinux/targeted/contexts/files/file_contexts'
+        self.disk_setup.get_disksize_mbytes.assert_called_once_with(
+            root_clone=0, boot_clone=0
         )
-        self.disk_setup.get_disksize_mbytes.assert_called_once_with()
         self.loop_provider.create.assert_called_once_with()
         self.disk.wipe.assert_called_once_with()
         self.disk.create_efi_csm_partition.assert_called_once_with(
@@ -322,7 +328,7 @@ class TestDiskBuilder:
             self.firmware.get_efi_partition_size()
         )
         self.disk.create_boot_partition.assert_called_once_with(
-            self.disk_setup.boot_partition_size()
+            self.disk_setup.boot_partition_size(), 0
         )
         self.disk.create_swap_partition.assert_called_once_with(
             '128'
@@ -331,7 +337,7 @@ class TestDiskBuilder:
             self.firmware.get_prep_partition_size()
         )
         self.disk.create_root_partition.assert_called_once_with(
-            'all_free'
+            'all_free', 0
         )
         self.disk.map_partitions.assert_called_once_with()
         self.bootloader_config.setup_disk_boot_images.assert_called_once_with(
@@ -411,6 +417,220 @@ class TestDiskBuilder:
             'target_dir'
         )
 
+    @patch('kiwi.builder.disk.VolumeManager.new')
+    @patch('kiwi.builder.disk.FileSystem.new')
+    @patch('kiwi.builder.disk.Command.run')
+    @patch('kiwi.builder.disk.Defaults.get_grub_boot_directory_name')
+    @patch('os.path.exists')
+    @patch('os.path.getsize')
+    @patch('kiwi.builder.disk.SystemSetup')
+    @patch('kiwi.builder.disk.ImageSystem')
+    @patch('kiwi.builder.disk.Temporary.new_file')
+    @patch('kiwi.builder.disk.CloneDevice')
+    def test_create_lvm_disk_standard_root_with_clone(
+        self, mock_CloneDevice, mock_Temporary_new_file, mock_ImageSystem,
+        mock_SystemSetup, mock_os_path_getsize, mock_path,
+        mock_grub_dir, mock_command, mock_fs, mock_volume_manager
+    ):
+        tempfile = Mock()
+        tempfile.name = 'tempfile'
+        mock_Temporary_new_file.return_value = tempfile
+        mock_os_path_getsize.return_value = 42
+        self.boot_image_task.get_boot_names.return_value = self.boot_names_type(
+            kernel_name='vmlinuz-1.2.3-default',
+            initrd_name='initramfs-1.2.3.img'
+        )
+        mock_path.return_value = True
+        filesystem = Mock()
+        filesystem.filename = ''
+        mock_fs.return_value = filesystem
+        self.disk_builder.custom_partitions = {
+            'var': ptable_entry_type(
+                mbsize=100,
+                clone=1,
+                partition_name='p.lxvar',
+                partition_type='t.linux',
+                mountpoint='/var',
+                filesystem='ext3'
+            )
+        }
+        volume_manager = Mock()
+        volume_manager.get_device = Mock(
+            return_value={
+                'root': MappedDevice('/dev/systemVG/LVRoot', Mock()),
+                'swap': MappedDevice('/dev/systemVG/LVSwap', Mock())
+            }
+        )
+        volume_manager.get_fstab = Mock(
+            return_value=['fstab_volume_entries']
+        )
+        mock_volume_manager.return_value = volume_manager
+        self.disk_builder.root_clone_count = 1
+        self.disk_builder.boot_clone_count = 1
+        self.disk_builder.volume_manager_name = 'lvm'
+        self.disk_builder.root_filesystem_is_overlay = False
+        self.disk_builder.initrd_system = 'dracut'
+        disk_system = Mock()
+        mock_SystemSetup.return_value = disk_system
+
+        self.device_map['rootclone1'] = MappedDevice('/dev/root-device', Mock())
+        self.device_map['bootclone1'] = MappedDevice('/dev/boot-device', Mock())
+        self.device_map['varclone1'] = MappedDevice('/dev/var-device', Mock())
+        # Test in lvm mode (no root overlay)
+        m_open = mock_open()
+        with patch('builtins.open', m_open, create=True):
+            self.disk_builder.create_disk()
+        volume_manager.\
+            umount_volumes.call_args_list[0].assert_called_once_with()
+
+    @patch('kiwi.builder.disk.FileSystem.new')
+    @patch('kiwi.builder.disk.Command.run')
+    @patch('kiwi.builder.disk.Defaults.get_grub_boot_directory_name')
+    @patch('os.path.exists')
+    @patch('os.path.getsize')
+    @patch('kiwi.builder.disk.SystemSetup')
+    @patch('kiwi.builder.disk.ImageSystem')
+    @patch('kiwi.builder.disk.Temporary.new_file')
+    @patch('kiwi.builder.disk.CloneDevice')
+    def test_create_disk_standard_root_with_clone(
+        self, mock_CloneDevice, mock_Temporary_new_file, mock_ImageSystem,
+        mock_SystemSetup, mock_os_path_getsize, mock_path,
+        mock_grub_dir, mock_command, mock_fs
+    ):
+        tempfile = Mock()
+        tempfile.name = 'tempfile'
+        mock_Temporary_new_file.return_value = tempfile
+        mock_os_path_getsize.return_value = 42
+        self.boot_image_task.get_boot_names.return_value = self.boot_names_type(
+            kernel_name='vmlinuz-1.2.3-default',
+            initrd_name='initramfs-1.2.3.img'
+        )
+        mock_path.return_value = True
+        filesystem = Mock()
+        filesystem.filename = ''
+        mock_fs.return_value = filesystem
+        self.disk_builder.custom_partitions = {
+            'var': ptable_entry_type(
+                mbsize=100,
+                clone=1,
+                partition_name='p.lxvar',
+                partition_type='t.linux',
+                mountpoint='/var',
+                filesystem='ext3'
+            )
+        }
+        self.disk_builder.root_clone_count = 1
+        self.disk_builder.boot_clone_count = 1
+        self.disk_builder.root_filesystem_is_overlay = False
+        self.disk_builder.volume_manager_name = None
+        self.disk_builder.initrd_system = 'dracut'
+        disk_system = Mock()
+        mock_SystemSetup.return_value = disk_system
+
+        self.device_map['rootclone1'] = MappedDevice('/dev/root-device', Mock())
+        self.device_map['bootclone1'] = MappedDevice('/dev/boot-device', Mock())
+        self.device_map['varclone1'] = MappedDevice('/dev/var-device', Mock())
+
+        # Test in standard mode (no root overlay)
+        m_open = mock_open()
+        with patch('builtins.open', m_open, create=True):
+            self.disk_builder.create_disk()
+
+        self.disk.create_boot_partition.assert_called_once_with(
+            self.disk_setup.boot_partition_size(), 1
+        )
+        self.disk.create_root_partition.assert_called_once_with(
+            'clone:all_free:458', 1
+        )
+        self.disk.create_custom_partitions.assert_called_once_with(
+            self.disk_builder.custom_partitions
+        )
+        assert mock_CloneDevice.return_value.clone.call_args_list == [
+            call([self.device_map['varclone1']]),
+            call([self.device_map['bootclone1']]),
+            call([self.device_map['rootclone1']])
+        ]
+
+        # Test in overlay mode a root clone is created from
+        # the root readonly partition and not from the root (rw)
+        # partition.
+        self.disk_builder.root_filesystem_is_overlay = True
+        self.disk.create_root_partition.reset_mock()
+        with patch('builtins.open', m_open, create=True):
+            self.disk_builder.create_disk()
+
+        self.disk.create_root_readonly_partition.assert_called_once_with(
+            10, 1
+        )
+        self.disk.create_root_partition.assert_called_once_with(
+            'all_free', 0
+        )
+
+        # Test in verity mode
+        self.disk_builder.root_filesystem_verity_blocks = 10
+        self.disk_builder.root_filesystem_is_overlay = False
+        mock_CloneDevice.reset_mock()
+        self.disk.create_root_partition.reset_mock()
+        with patch('builtins.open', m_open, create=True):
+            self.disk_builder.create_disk()
+
+        filesystem.create_verity_layer.assert_called_once_with(10, 'tempfile')
+        assert mock_CloneDevice.return_value.clone.call_args_list == [
+            call([self.device_map['varclone1']]),
+            call([self.device_map['bootclone1']]),
+            call([self.device_map['rootclone1']])
+        ]
+
+    @patch('kiwi.builder.disk.FileSystem.new')
+    @patch('kiwi.builder.disk.Command.run')
+    @patch('kiwi.builder.disk.Defaults.get_grub_boot_directory_name')
+    @patch('os.path.exists')
+    @patch('os.path.getsize')
+    @patch('kiwi.builder.disk.SystemSetup')
+    @patch('kiwi.builder.disk.ImageSystem')
+    @patch('kiwi.builder.disk.Temporary.new_file')
+    def test_create_disk_standard_root_with_dm_integrity(
+        self, mock_Temporary_new_file, mock_ImageSystem,
+        mock_SystemSetup, mock_os_path_getsize, mock_path,
+        mock_grub_dir, mock_command, mock_fs
+    ):
+        tempfile = Mock()
+        tempfile.name = 'tempfile'
+        mock_Temporary_new_file.return_value = tempfile
+        mock_os_path_getsize.return_value = 42
+        self.boot_image_task.get_boot_names.return_value = self.boot_names_type(
+            kernel_name='vmlinuz-1.2.3-default',
+            initrd_name='initramfs-1.2.3.img'
+        )
+        mock_path.return_value = True
+        filesystem = Mock()
+        mock_fs.return_value = filesystem
+        self.disk_builder.integrity_root = True
+        self.disk_builder.root_filesystem_embed_integrity_metadata = True
+        self.disk_builder.root_filesystem_is_overlay = False
+        self.disk_builder.volume_manager_name = None
+        self.disk_builder.initrd_system = 'dracut'
+        disk_system = Mock()
+        mock_SystemSetup.return_value = disk_system
+
+        m_open = mock_open()
+        with patch('builtins.open', m_open, create=True):
+            self.disk_builder.create_disk()
+
+        self.integrity_root.create_integritytab.assert_called_once_with(
+            'root_dir/etc/integritytab'
+        )
+        self.integrity_root.create_integrity_metadata.assert_called_once_with()
+        self.integrity_root.sign_integrity_metadata.assert_called_once_with()
+        self.integrity_root.write_integrity_metadata.assert_called_once_with()
+        assert filesystem.create_on_device.call_args_list == [
+            call(label='EFI'),
+            call(label='BOOT'),
+            # root must be created DM_METADATA_OFFSET smaller
+            call(label='ROOT', size=-4096, unit='b'),
+            call(label='SWAP')
+        ]
+
     @patch('kiwi.builder.disk.FileSystem.new')
     @patch('random.randrange')
     @patch('kiwi.builder.disk.Command.run')
@@ -452,10 +672,9 @@ class TestDiskBuilder:
             self.disk_builder.create_disk()
 
         self.setup.create_recovery_archive.assert_called_once_with()
-        self.setup.set_selinux_file_contexts.assert_called_once_with(
-            '/etc/selinux/targeted/contexts/files/file_contexts'
+        self.disk_setup.get_disksize_mbytes.assert_called_once_with(
+            root_clone=0, boot_clone=0
         )
-        self.disk_setup.get_disksize_mbytes.assert_called_once_with()
         assert self.loop_provider.create.call_args_list == [
             call(), call()
         ]
@@ -467,13 +686,13 @@ class TestDiskBuilder:
             self.firmware.get_efi_partition_size()
         )
         self.disk.create_boot_partition.assert_called_once_with(
-            self.disk_setup.boot_partition_size()
+            self.disk_setup.boot_partition_size(), 0
         )
         self.disk.create_prep_partition.assert_called_once_with(
             self.firmware.get_prep_partition_size()
         )
         self.disk.create_root_partition.assert_called_once_with(
-            'all_free'
+            'all_free', 0
         )
         self.disk.map_partitions.assert_called_once_with()
         self.bootloader_config.setup_disk_boot_images.assert_called_once_with(
@@ -591,6 +810,8 @@ class TestDiskBuilder:
         self.disk_builder.root_filesystem_has_write_partition = False
         self.disk_builder.root_filesystem_verity_blocks = 10
         self.disk_builder.root_filesystem_embed_verity_metadata = True
+        self.disk_builder.integrity_root = True
+        self.disk_builder.root_filesystem_embed_integrity_metadata = True
         self.disk_builder.volume_manager_name = None
         squashfs = Mock()
         mock_squashfs.return_value = squashfs
@@ -627,14 +848,19 @@ class TestDiskBuilder:
         ]
         squashfs.create_verity_layer.assert_called_once_with(10)
         squashfs.create_verification_metadata.assert_called_once_with(
-            '/dev/readonly-root-device'
+            '/dev/integrityRoot'
+        )
+        self.integrity_root.create_integrity_metadata.assert_called_once_with()
+        self.integrity_root.sign_integrity_metadata.assert_called_once_with()
+        self.integrity_root.write_integrity_metadata.assert_called_once_with()
+        self.disk.create_root_readonly_partition.assert_called_once_with(
+            11, 0
         )
-        self.disk.create_root_readonly_partition.assert_called_once_with(11)
         assert mock_command.call_args_list[2] == call(
-            ['blockdev', '--getsize64', '/dev/readonly-root-device']
+            ['blockdev', '--getsize64', '/dev/integrityRoot']
         )
         assert mock_command.call_args_list[3] == call(
-            ['dd', 'if=kiwi-tempname', 'of=/dev/readonly-root-device']
+            ['dd', 'if=kiwi-tempname', 'of=/dev/integrityRoot']
         )
         assert m_open.return_value.write.call_args_list == [
             # config.partids
@@ -742,7 +968,7 @@ class TestDiskBuilder:
             self.disk_builder.create_disk()
 
         self.disk.create_root_raid_partition.assert_called_once_with(
-            'all_free'
+            'all_free', 0
         )
         self.raid_root.create_degraded_raid.assert_called_once_with(
             raid_level='mirroring'
@@ -796,20 +1022,56 @@ class TestDiskBuilder:
     @patch('kiwi.builder.disk.Command.run')
     @patch('kiwi.builder.disk.Defaults.get_grub_boot_directory_name')
     @patch('os.path.exists')
+    @patch('kiwi.builder.disk.BlockID')
     def test_create_disk_uses_custom_partitions(
-        self, mock_exists, mock_grub_dir, mock_command, mock_fs
+        self, mock_BlockID, mock_exists, mock_grub_dir, mock_command, mock_fs
     ):
+        self.fstype_mock_list = [
+            'ext3',
+            'squashfs',
+            'some_fs',
+            'some_fs',
+            'some_fs',
+            'some_fs',
+            'some_fs',
+            'some_fs',
+            'some_fs',
+            'some_fs',
+            'some_fs',
+            'some_fs'
+        ]
+        fstype = list(self.fstype_mock_list)
+
+        def get_filesystem():
+            return fstype.pop()
+
+        block_operation = Mock()
+        block_operation.get_filesystem.side_effect = get_filesystem
+        block_operation.get_blkid.return_value = 'blkid_result'
+
+        mock_BlockID.return_value = block_operation
+
         mock_exists.return_value = True
         self.disk_builder.custom_partitions = {
             'var': ptable_entry_type(
                 mbsize=100,
+                clone=0,
                 partition_name='p.lxvar',
                 partition_type='t.linux',
                 mountpoint='/var',
                 filesystem='ext3'
+            ),
+            'spare': ptable_entry_type(
+                mbsize=100,
+                clone=0,
+                partition_name='p.lxtmp',
+                partition_type='t.linux',
+                mountpoint='/spare',
+                filesystem='squashfs'
             )
         }
         self.disk_builder.volume_manager_name = None
+
         filesystem = Mock()
         mock_fs.return_value = filesystem
 
@@ -821,21 +1083,27 @@ class TestDiskBuilder:
             self.disk_builder.custom_partitions
         )
         assert [
-            call('UUID=blkid_result /var blkid_result_fs defaults 0 0')
+            call('PARTUUID=blkid_result /spare squashfs defaults 0 0')
+        ] in self.disk_builder.fstab.add_entry.call_args_list
+
+        assert [
+            call('UUID=blkid_result /var ext3 defaults 0 0')
         ] in self.disk_builder.fstab.add_entry.call_args_list
 
         self.disk_builder.persistency_type = 'by-partuuid'
+        fstype = list(self.fstype_mock_list)
         with patch('builtins.open'):
             self.disk_builder.create_disk()
         assert [
-            call('PARTUUID=blkid_result /var blkid_result_fs defaults 0 0')
+            call('PARTUUID=blkid_result /var ext3 defaults 0 0')
         ] in self.disk_builder.fstab.add_entry.call_args_list
 
         self.disk_builder.persistency_type = 'by-label'
+        fstype = list(self.fstype_mock_list)
         with patch('builtins.open'):
             self.disk_builder.create_disk()
         assert [
-            call('LABEL=blkid_result /var blkid_result_fs defaults 0 0')
+            call('LABEL=blkid_result /var ext3 defaults 0 0')
         ] in self.disk_builder.fstab.add_entry.call_args_list
 
     @patch('kiwi.builder.disk.FileSystem.new')
@@ -867,7 +1135,9 @@ class TestDiskBuilder:
         with patch('builtins.open'):
             self.disk_builder.create_disk()
 
-        self.disk.create_root_lvm_partition.assert_called_once_with('all_free')
+        self.disk.create_root_lvm_partition.assert_called_once_with(
+            'all_free', 0
+        )
         volume_manager.setup.assert_called_once_with('systemVG')
         volume_manager.create_volumes.assert_called_once_with('btrfs')
         volume_manager.mount_volumes.call_args_list[0].assert_called_once_with()
@@ -925,6 +1195,26 @@ class TestDiskBuilder:
 
         self.disk.create_mbr.assert_called_once_with()
 
+    @patch('kiwi.builder.disk.FileSystem.new')
+    @patch('kiwi.builder.disk.Command.run')
+    @patch('kiwi.builder.disk.Defaults.get_grub_boot_directory_name')
+    def test_create_disk_custom_start_sector_requested(
+        self, mock_grub_dir, mock_command, mock_fs
+    ):
+        filesystem = Mock()
+        mock_fs.return_value = filesystem
+        self.disk_builder.volume_manager_name = None
+        self.disk_builder.install_media = False
+        self.disk_builder.disk_start_sector = 4096
+        self.firmware.efi_mode = Mock(
+            return_value=None
+        )
+
+        with patch('builtins.open'):
+            self.disk_builder.create_disk()
+
+        self.disk.set_start_sector.assert_called_once_with(4096)
+
     def test_create(self):
         result = Mock()
         create_disk = Mock(return_value=result)
