@@ -131,8 +131,9 @@ class TestInstallImageBuilder:
     @patch('kiwi.builder.install.Temporary')
     @patch('kiwi.builder.install.Command.run')
     @patch('kiwi.builder.install.Defaults.get_grub_boot_directory_name')
+    @patch('kiwi.builder.install.Iso')
     def test_create_install_iso(
-        self, mock_grub_dir, mock_command, mock_Temporary, mock_copy,
+        self, mock_Iso, mock_grub_dir, mock_command, mock_Temporary, mock_copy,
         mock_setup_media_loader_directory, mock_BootLoaderConfig,
         mock_DeviceProvider
     ):
@@ -154,6 +155,8 @@ class TestInstallImageBuilder:
         mock_BootLoaderConfig.return_value = bootloader_config
         mock_Temporary.side_effect = side_effect
 
+        self.firmware.bios_mode.return_value = False
+
         m_open = mock_open()
         with patch('builtins.open', m_open, create=True):
             self.install_image.create_install_iso()
@@ -260,10 +263,12 @@ class TestInstallImageBuilder:
         mock_BootLoaderConfig.reset_mock()
         tmp_names = [temp_esp_file, temp_squashfs, temp_media_dir]
         self.firmware.efi_mode.return_value = None
+        self.firmware.bios_mode.return_value = True
 
         with patch('builtins.open', m_open, create=True):
             self.install_image.create_install_iso()
 
+        mock_Iso.return_value.setup_isolinux_boot_path.assert_called_once_with()
         mock_BootLoaderConfig.assert_called_once_with(
             'isolinux', self.xml_state, root_dir='root_dir',
             boot_dir='temp_media_dir'
@@ -276,6 +281,7 @@ class TestInstallImageBuilder:
     def test_create_install_iso_no_kernel_found(
         self, mock_command, mock_Temporary, mock_setup_media_loader_directory
     ):
+        self.firmware.bios_mode.return_value = False
         self.kernel.get_kernel.return_value = False
         with patch('builtins.open'):
             with raises(KiwiInstallBootImageError):
@@ -287,6 +293,7 @@ class TestInstallImageBuilder:
     def test_create_install_iso_no_hypervisor_found(
         self, mock_command, mock_Temporary, mock_setup_media_loader_directory
     ):
+        self.firmware.bios_mode.return_value = False
         self.kernel.get_xen_hypervisor.return_value = False
         with patch('builtins.open'):
             with raises(KiwiInstallBootImageError):
@@ -299,6 +306,7 @@ class TestInstallImageBuilder:
     def test_create_install_pxe_no_kernel_found(
         self, mock_compress, mock_md5, mock_command, mock_Temporary
     ):
+        self.firmware.bios_mode.return_value = False
         mock_Temporary.return_value.new_dir.return_value.name = 'tmpdir'
         self.kernel.get_kernel.return_value = False
         with patch('builtins.open'):
@@ -314,6 +322,7 @@ class TestInstallImageBuilder:
         self, mock_symlink, mock_compress, mock_md5, mock_command,
         mock_Temporary
     ):
+        self.firmware.bios_mode.return_value = False
         mock_Temporary.return_value.new_dir.return_value.name = 'tmpdir'
         self.kernel.get_xen_hypervisor.return_value = False
         with patch('builtins.open'):
