@@ -1,5 +1,8 @@
+import logging
 from mock import patch
-from pytest import raises
+from pytest import (
+    raises, fixture
+)
 import mock
 
 import kiwi.defaults as defaults
@@ -10,6 +13,10 @@ from kiwi.exceptions import KiwiFileSystemSyncError
 
 
 class TestFileSystemBase:
+    @fixture(autouse=True)
+    def inject_fixtures(self, caplog):
+        self._caplog = caplog
+
     def setup(self):
         provider = mock.Mock()
         provider.get_device = mock.Mock(
@@ -103,6 +110,12 @@ class TestFileSystemBase:
         self.fsbase.umount()
         mount.umount.assert_called_once_with()
 
+    def test_mount(self):
+        mount = mock.Mock()
+        self.fsbase.filesystem_mount = mount
+        self.fsbase.mount()
+        mount.mount.assert_called_once_with([])
+
     def test_fs_size(self):
         # size of 100k must be 100k (default unit)
         assert self.fsbase._fs_size(100) == '100'
@@ -117,7 +130,10 @@ class TestFileSystemBase:
         # size of 1073741824b - 1g must be zero
         assert self.fsbase._fs_size(-1, unit=defaults.UNIT.gb) == '0'
 
+    def test_set_uuid(self):
+        with self._caplog.at_level(logging.WARNING):
+            self.fsbase.set_uuid()
+
     def test_destructor_valid_mountpoint(self):
         self.fsbase.filesystem_mount = mock.Mock()
         self.fsbase.__del__()
-        assert self.fsbase.filesystem_mount is None
